@@ -3,11 +3,8 @@ from typing import Callable, Dict, List, Optional, Tuple, Union
 from pydantic import Field
 import inspect
 from rekuest.actors.base import Actor
-from rekuest.actors.transport import ActorTransport, SharedTransport
-from rekuest.actors.types import ActorBuilder
+from rekuest.actors.builder import ActorBuilder
 from rekuest.agents.errors import ProvisionException
-from rekuest.agents.transport.mock import MockAgentTransport
-from rekuest.agents.transport.websocket import WebsocketAgentTransport
 from rekuest.api.schema import (
     ProvisionFragment,
     TemplateFragment,
@@ -79,13 +76,6 @@ class BaseAgent(KoiledModel):
         )
 
     async def aregister_definitions(self):
-        if self.definition_registry.templated_nodes:
-            for (
-                q_string,
-                actor_builder,
-                params,
-            ) in self.definition_registry.templated_nodes:
-                raise NotImplementedError("This method is not yet functional.")
 
         if self.definition_registry.defined_nodes:
             for (
@@ -105,24 +95,18 @@ class BaseAgent(KoiledModel):
                     (arkitekt_template, actor_builder, params)
                 )
 
-        if self._approved_templates:
-
-            for arkitekt_template, defined_actor, params in self._approved_templates:
-                # Generating Maps for Easy access
-                self._templateActorBuilderMap[arkitekt_template.id] = defined_actor
+                self._templateActorBuilderMap[arkitekt_template.id] = actor_builder
                 self._templateTemplatesMap[arkitekt_template.id] = arkitekt_template
 
     async def aspawn_actor(self, prov: Provision) -> Actor:
         """Spawns an Actor from a Provision"""
         try:
             actor_builder = self._templateActorBuilderMap[prov.template]
-            template = self._templateTemplatesMap[prov.template]
         except KeyError as e:
             raise ProvisionException("No Actor Builder found for template") from e
-        actor = actor_builder(
-            provision=prov, transport=self.transport, template=template
-        )
-        await actor.arun()
+        actor = actor_builder(provision=prov, transport=self.transport)
+        task = await actor.arun()
+        task.add_done_callback(print)
         self.provisionActorMap[prov.provision] = actor
         return actor
 
