@@ -1,7 +1,7 @@
 from contextlib import nullcontext
 from enum import Enum
 from random import choices
-from typing import Any, Callable, List, Tuple
+from typing import Any, Callable, List, Tuple, Type
 import inflection
 from rekuest.api.schema import (
     ArgPortInput,
@@ -11,6 +11,7 @@ from rekuest.api.schema import (
     PortKindInput,
     ReturnPortInput,
     WidgetInput,
+    AnnotationInput,
 )
 import inspect
 from docstring_parser import parse
@@ -22,12 +23,24 @@ from rekuest.structures.registry import (
 
 
 def convert_child_to_childport(
-    cls,
+    cls: Type,
     registry: StructureRegistry,
-    nullable=False,
-    is_return=False,
-    annotations=None,
+    nullable: bool = False,
+    is_return: bool = False,
+    annotations: List[AnnotationInput] = None,
 ) -> Tuple[ChildPortInput, WidgetInput, Callable]:
+    """Converts a element of a annotation to a child port
+
+    Args:
+        cls (Type): The type (class or annotation) of the elemtn
+        registry (StructureRegistry): The structure registry to use
+        nullable (bool, optional): Is this type optional (recursive parameter). Defaults to False.
+        is_return (bool, optional): Is this a return type?. Defaults to False.
+        annotations (List[AnnotationInput], optional): The annotations for this element. Defaults to None.
+
+    Returns:
+        Tuple[ChildPortInput, WidgetInput, Callable]: The child port, the widget and the converter for the default
+    """
 
     if hasattr(cls, "__name__") and cls.__name__ == "Annotated":
         real_type = cls.__args__[0]
@@ -307,10 +320,27 @@ def convert_return_to_returnport(
     description=None,
     widget=None,
     nullable=False,
+    annotations=None,
 ) -> ReturnPortInput:
     """
     Convert a class to an ArgPort
     """
+    if hasattr(cls, "__name__") and cls.__name__ == "Annotated":
+        real_type = cls.__args__[0]
+
+        annotations = [
+            registry.get_converter_for_annotation(i.__class__)(i)
+            for i in cls.__metadata__
+        ]
+
+        return convert_return_to_returnport(
+            real_type,
+            key,
+            registry,
+            widget=widget,
+            nullable=nullable,
+            annotations=annotations,
+        )
 
     if cls.__module__ == "typing":
 
@@ -327,6 +357,7 @@ def convert_return_to_returnport(
                     child=child.dict(exclude={"key"}),
                     nullable=nullable,
                     description=description,
+                    annotations=annotations,
                 )
 
             if cls._name == "Dict":
@@ -340,6 +371,7 @@ def convert_return_to_returnport(
                     child=child.dict(exclude={"key"}),
                     nullable=nullable,
                     description=description,
+                    annotations=annotations,
                 )
 
         if hasattr(cls, "__args__"):
@@ -357,6 +389,7 @@ def convert_return_to_returnport(
                 key=key,
                 nullable=nullable,
                 description=description,
+                annotations=annotations,
             )  # catch bool is subclass of int
         if not issubclass(cls, Enum) and issubclass(cls, int):
             return ReturnPortInput(
@@ -364,6 +397,7 @@ def convert_return_to_returnport(
                 key=key,
                 nullable=nullable,
                 description=description,
+                annotations=annotations,
             )
         if not issubclass(cls, Enum) and issubclass(cls, float):
             return ReturnPortInput(
@@ -371,6 +405,7 @@ def convert_return_to_returnport(
                 key=key,
                 nullable=nullable,
                 description=description,
+                annotations=annotations,
             )
         if not issubclass(cls, Enum) and issubclass(cls, str):
             return ReturnPortInput(
@@ -378,6 +413,7 @@ def convert_return_to_returnport(
                 key=key,
                 nullable=nullable,
                 description=description,
+                annotations=annotations,
             )
 
     identifier = registry.get_identifier_for_structure(cls)
@@ -390,6 +426,7 @@ def convert_return_to_returnport(
         widget=widget,
         nullable=nullable,
         description=None,
+        annotations=annotations,
     )
 
 
@@ -397,9 +434,9 @@ def prepare_definition(
     function: Callable,
     structure_registry: StructureRegistry,
     interface=None,
-    widgets={},
+    widgets=None,
     allow_empty_doc=False,
-    interfaces=[],
+    interfaces=None,
     omitfirst=None,
     omitlast=None,
     omitkeys=[],
@@ -426,6 +463,8 @@ def prepare_definition(
     )
 
     sig = inspect.signature(function)
+    widgets = widgets or {}
+    interfaces = interfaces or []
 
     # Generate Args and Kwargs from the Annotation
     args: List[ArgPortInput] = []
