@@ -10,6 +10,8 @@ from rekuest.api.schema import (
     PortKind,
     ReturnPortFragment,
     ChildPortFragment,
+    DefinitionInput,
+    DefinitionFragment,
 )
 from rekuest.structures.errors import (
     PortShrinkingError,
@@ -17,6 +19,7 @@ from rekuest.structures.errors import (
     PortExpandingError,
     StructureExpandingError,
 )
+from rekuest.definition.validate import auto_validate
 
 
 async def aexpand_arg(
@@ -101,7 +104,7 @@ async def aexpand_arg(
 
 
 async def expand_inputs(
-    node: NodeFragment,
+    definition: DefinitionInput | DefinitionFragment,
     args: List[Union[str, int, float, dict, list]],
     structure_registry: StructureRegistry,
     skip_expanding: bool = False,
@@ -116,6 +119,11 @@ async def expand_inputs(
     """
 
     expanded_args = []
+    node = (
+        auto_validate(definition)
+        if isinstance(definition, DefinitionInput)
+        else definition
+    )
 
     if not skip_expanding:
         try:
@@ -215,12 +223,18 @@ async def ashrink_return(
 
 
 async def shrink_outputs(
-    node: NodeFragment,
+    definition: DefinitionInput | DefinitionFragment,
     returns: List[Any],
     structure_registry: StructureRegistry,
     skip_shrinking: bool = False,
 ) -> Tuple[Union[str, int, float, dict, list, None]]:
 
+    node = (
+        auto_validate(definition)
+        if isinstance(definition, DefinitionInput)
+        else definition
+    )
+
     if returns is None:
         returns = ()
     if not isinstance(returns, tuple):
